==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/GCPPlatformStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GCPPlatformStatusBuilder extends io.fabric8.openshift.api.model.GCPPlatformStatusFluentImpl<io.fabric8.openshift.api.model.GCPPlatformStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GCPPlatformStatus,io.fabric8.openshift.api.model.GCPPlatformStatusBuilder>{
  public GCPPlatformStatusBuilder() {
    this(false);
  }
  public GCPPlatformStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new GCPPlatformStatus(), validationEnabled);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GCPPlatformStatus(), validationEnabled);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent,io.fabric8.openshift.api.model.GCPPlatformStatus instance) {
    this(fluent, instance, false);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent,io.fabric8.openshift.api.model.GCPPlatformStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProjectID(instance.getProjectID()); 
    fluent.withRegion(instance.getRegion()); 
    this.validationEnabled = validationEnabled; 
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatus instance) {
    this(instance,false);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProjectID(instance.getProjectID()); 
    this.withRegion(instance.getRegion()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GCPPlatformStatus build() {
    GCPPlatformStatus buildable = new GCPPlatformStatus(fluent.getProjectID(),fluent.getRegion());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GCPPlatformStatusBuilder that = (GCPPlatformStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/GCPPlatformStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GCPPlatformStatusBuilder extends io.fabric8.openshift.api.model.GCPPlatformStatusFluentImpl<io.fabric8.openshift.api.model.GCPPlatformStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GCPPlatformStatus,io.fabric8.openshift.api.model.GCPPlatformStatusBuilder>{
  public GCPPlatformStatusBuilder() {
    this(false);
  }
  public GCPPlatformStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new GCPPlatformStatus(), validationEnabled);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GCPPlatformStatus(), validationEnabled);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent,io.fabric8.openshift.api.model.GCPPlatformStatus instance) {
    this(fluent, instance, false);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent,io.fabric8.openshift.api.model.GCPPlatformStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProjectID(instance.getProjectID()); 
    fluent.withRegion(instance.getRegion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatus instance) {
    this(instance,false);
  }
  public GCPPlatformStatusBuilder(io.fabric8.openshift.api.model.GCPPlatformStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProjectID(instance.getProjectID()); 
    this.withRegion(instance.getRegion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GCPPlatformStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GCPPlatformStatus build() {
    GCPPlatformStatus buildable = new GCPPlatformStatus(fluent.getProjectID(),fluent.getRegion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GCPPlatformStatusBuilder that = (GCPPlatformStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
